# Getestet mit Python 3.11.6 und PySide 6.5.3

import PySide6.QtWidgets as widgets
import PySide6.QtCore as core
import PySide6.QtGui as gui

class MeinWidget(widgets.QWidget):
    def __init__(self, parent : widgets.QWidget|None = None):
        super().__init__(parent)
        self.setCursor(core.Qt.CursorShape.BlankCursor)
        self.setAttribute(core.Qt.WidgetAttribute.WA_AcceptTouchEvents)
        self._img = gui.QImage(2000, 2000, gui.QImage.Format.Format_RGB32) # Besser automatisch an jeweilige Größe anpassen
        self._img.fill(core.Qt.GlobalColor.white)
        self._colors = [core.Qt.GlobalColor.black, core.Qt.GlobalColor.red, core.Qt.GlobalColor.green, core.Qt.GlobalColor.blue, core.Qt.GlobalColor.yellow, core.Qt.GlobalColor.magenta, core.Qt.GlobalColor.gray]

    def paintEvent(self, event: gui.QPaintEvent) -> None:
        super().paintEvent(event)
        painter = gui.QPainter(self)
        painter.drawImage(0, 0, self._img)
        painter.end()

    def event(self, event: core.QEvent) -> bool:
        if isinstance(event, gui.QTouchEvent):
            if event.type() in [core.QEvent.Type.TouchBegin, core.QEvent.Type.TouchUpdate]:
                tp = event.points()
                imgPainter = gui.QPainter(self._img)
                for p in tp:
                    c = self._colors[p.id() % len(self._colors)]
                    imgPainter.setBrush(c)
                    if p.state() in [gui.QEventPoint.State.Pressed, gui.QEventPoint.State.Updated]:
                        pen = gui.QPen(c)
                        pen.setWidth(40)
                        pen.setCapStyle(core.Qt.PenCapStyle.RoundCap)
                        imgPainter.setPen(pen)
                        imgPainter.drawLine(p.lastPos(), p.pos())
                imgPainter.end()
                self.update()
            return True
        else:
            return super().event(event)
        
    def erase(self) -> None:
        self._img.fill(core.Qt.GlobalColor.white)
        self.update()
